==> polls-v1.4.1.zip: polls/messages/pl/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Uwaga:</strong> Wynik głosowania jest ukryty dopóki ankieta nie zostanie zamknięta przez moderatora.',
    'Access denied!' => 'Brak dostępu!',
    'Add answer...' => 'Dodaj odpowiedź...',
    'Again? ;Weary;' => 'Znowu? ;Zmęczony;',
    'Allows the user to create polls' => 'Pozwalaj użytkownikom na tworzenie ankiet',
    'Allows to start polls.' => 'Pozwala dodawać głosowania.',
    'Anonymous' => 'Anonimowo',
    'Anonymous Votes?' => 'Głosy anonimowe?',
    'Anonymous poll!' => 'Głosowanie anonimowe!',
    'Answers' => 'Odpowiedzi',
    'At least one answer is required' => 'Przynajmniej jedna odpowiedź jest wymagana',
    'Cancel' => 'Anuluj',
    'Close Poll' => 'Zakończ głosowanie',
    'Closed' => 'Zamknięte',
    'Club A Steakhouse' => 'Stek',
    'Could not load poll!' => 'Nie można wczytać głosowania!',
    'Create poll' => 'Utwórz ankietę',
    'Description' => 'Opis',
    'Display answers in random order?' => 'Wyświetlaj odpowiedzi w losowej kolejności?',
    'Edit answer (empty answers will be removed)...' => 'Edytuj odpowiedź (puste odpowiedzi zostaną usunięte)...',
    'Edit your poll question...' => 'Edytuj pytanie głosowania...',
    'Hide results until poll is closed?' => 'Ukryć wyniki do momentu aż ankieta nie zostanie zamknięta?',
    'Invalid answer!' => 'Nieprawidłowa odpowiedź!',
    'Location of the next meeting' => 'Miejsce następnego spotkania',
    'Multiple answers per user' => 'Wielokrotne odpowiedzi na użytkownika',
    'Pisillo Italian Panini' => 'Włoskie Panini',
    'Please specify at least {min} answers!' => 'Proszę określ przynajmniej {min} odpowiedzi!',
    'Poll' => 'Pytanie',
    'Polls' => 'Głosowania',
    'Question' => 'Pytanie',
    'Reopen Poll' => 'Wznów głosowanie',
    'Reset my vote' => 'Resetuj mój głos',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Planujemy właśnie etapy naszego kolejnego spotkania, chcemy się dowiedzieć gdzie chcesz się spotkać?',
    'Save' => 'Zapisz',
    'To Daniel' => 'Do Daniela',
    'Users voted for: <strong>{answer}</strong>' => 'Użytkownicy głosowali na: <strong>{answer}</strong>',
    'Vote' => 'Głos',
    'Voting for multiple answers is disabled!' => 'Głosowanie na wielokrotne odpowiedzi jest zabronione!',
    'Whenever someone participates in a poll.' => 'Za każdym razem gdy ktoś wypełni głosowanie.',
    'Why don\'t we go to Bemelmans Bar?' => 'Dlaczego nie skoczymy do Baru Mlecznego?',
    'You have insufficient permissions to perform that operation!' => 'Masz niewystarczające uprawnienia aby przeprowadzić tę operację!',
    'and {count} more vote for this.' => 'i {count} więcej głosów.',
    'votes' => 'głosy',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}głos{htmlTagEnd}}other{# {htmlTagBegin}głosów{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} odpowiedział(a) na {question}.',
    'Poll content ID' => '',
];

==> polls-v1.4.2.zip: polls/messages/pl/base.php <==
<?php

return [
    '<strong>Note:</strong> The result is hidden until the poll is closed by a moderator.' => '<strong>Uwaga:</strong> Wynik głosowania jest ukryty dopóki ankieta nie zostanie zamknięta przez moderatora.',
    'Access denied!' => 'Brak dostępu!',
    'Add answer...' => 'Dodaj odpowiedź...',
    'Again? :weary:' => 'Znowu? ;Zmęczony;',
    'Allows the user to create polls' => 'Pozwalaj użytkownikom na tworzenie ankiet',
    'Allows to start polls.' => 'Pozwala dodawać głosowania.',
    'Anonymous' => 'Anonimowo',
    'Anonymous Votes?' => 'Głosy anonimowe?',
    'Anonymous poll!' => 'Głosowanie anonimowe!',
    'Answers' => 'Odpowiedzi',
    'At least one answer is required' => 'Przynajmniej jedna odpowiedź jest wymagana',
    'Cancel' => 'Anuluj',
    'Close Poll' => 'Zakończ głosowanie',
    'Closed' => 'Zamknięte',
    'Club A Steakhouse' => 'Stek',
    'Could not load poll!' => 'Nie można wczytać głosowania!',
    'Create poll' => 'Utwórz ankietę',
    'Description' => 'Opis',
    'Display answers in random order?' => 'Wyświetlaj odpowiedzi w losowej kolejności?',
    'Edit answer (empty answers will be removed)...' => 'Edytuj odpowiedź (puste odpowiedzi zostaną usunięte)...',
    'Edit your poll question...' => 'Edytuj pytanie głosowania...',
    'Hide results until poll is closed?' => 'Ukryć wyniki do momentu aż ankieta nie zostanie zamknięta?',
    'Invalid answer!' => 'Nieprawidłowa odpowiedź!',
    'Location of the next meeting' => 'Miejsce następnego spotkania',
    'Multiple answers per user' => 'Wielokrotne odpowiedzi na użytkownika',
    'Pisillo Italian Panini' => 'Włoskie Panini',
    'Please specify at least {min} answers!' => 'Proszę określ przynajmniej {min} odpowiedzi!',
    'Poll' => 'Pytanie',
    'Polls' => 'Głosowania',
    'Question' => 'Pytanie',
    'Reopen Poll' => 'Wznów głosowanie',
    'Reset my vote' => 'Resetuj mój głos',
    'Right now, we are in the planning stages for our next meetup and we would like to know from you, where you would like to go?' => 'Planujemy właśnie etapy naszego kolejnego spotkania, chcemy się dowiedzieć gdzie chcesz się spotkać?',
    'Save' => 'Zapisz',
    'To Daniel' => 'Do Daniela',
    'Users voted for: <strong>{answer}</strong>' => 'Użytkownicy głosowali na: <strong>{answer}</strong>',
    'Vote' => 'Głos',
    'Voting for multiple answers is disabled!' => 'Głosowanie na wielokrotne odpowiedzi jest zabronione!',
    'Whenever someone participates in a poll.' => 'Za każdym razem gdy ktoś wypełni głosowanie.',
    'Why don\'t we go to Bemelmans Bar?' => 'Dlaczego nie skoczymy do Baru Mlecznego?',
    'You have insufficient permissions to perform that operation!' => 'Masz niewystarczające uprawnienia aby przeprowadzić tę operację!',
    'and {count} more vote for this.' => 'i {count} więcej głosów.',
    'votes' => 'głosy',
    '{n,plural,=1{# {htmlTagBegin}vote{htmlTagEnd}}other{# {htmlTagBegin}votes{htmlTagEnd}}}' => '{n,plural,=1{# {htmlTagBegin}głos{htmlTagEnd}}other{# {htmlTagBegin}głosów{htmlTagEnd}}}',
    '{userName} answered the {question}.' => '{userName} odpowiedział(a) na {question}.',
    'Poll content ID' => '',
];
